package jiayue

import (
	"database/sql"
	"eta/eta_bridge/global"
	"fmt"
)

func GetDictIndex(condition string, pars []interface{}) (dictIndexList []DictIndex, err error) {
	selectVals := "ID, CODE, NAME, UNIT, FREQUENCY, DESCRIPTION, TABLE_NAME, SOURCE_TYPE, SOURCE_CODE, SOURCE_DESCRIPTION, INDUSTRY, TYPE, COMMODITY, SJB_ID, USER_ID, ROWS_COUNT, DATE_FIRST, DATE_LAST, TIME_LAST_UPDATE, TIME_LAST_REQUEST, PRIORITY, STATUS, SHORT_NAME, UPDATE_DESCRIPTION, FORECAST_FLAG, MANUAL_FLAG, VARIABLE_FLAG, MARKETDATA_FLAG, CREATE_USER, CREATE_TIME, UPDATE_USER, UPDATE_TIME"
	sqlStatement := fmt.Sprintf("SELECT %s FROM DICT_INDEX WHERE %s", selectVals, condition)
	dictIndexList, err = getDictIndex(sqlStatement, pars)
	if err != nil {
		fmt.Printf("查询指标信息失败 %s", err)
		return
	}
	fmt.Printf("查询指标信息成功")
	return
}

func GetDictData(tableName string, condition string, pars []interface{}) (dictIndexData []DictData, err error) {
	sqlStatement := fmt.Sprintf("SELECT ID, INDEX_ID, INDEX_VALUE, INDEX_DATE, UPDATE_TIME FROM %s WHERE %s", tableName, condition)

	dictIndexData, err = getDictData(sqlStatement, pars)
	if err != nil {
		fmt.Printf("查询指标信息失败 %s", err)
		return
	}
	fmt.Printf("查询指标信息成功")
	return
}

type DictIndex struct {
	Id                int    `description:"主键"`
	Code              string `description:"指标编码"`
	Name              string `description:"指标名称"`
	Unit              string `description:"单位"`
	Frequency         string `description:"更新频率"`
	Description       string `description:"描述"`
	TableName         string `description:"指标数据存储库表"`
	SourceType        string `description:"指标来源，如：wind：万德;manual：手工导入;formula：公式;webisite：网页爬取"`
	SourceCode        string `description:"来源编码"`
	SourceDescription string `description:"来源说明"`
	Industry          string `description:"品种板块"`
	Type              string `description:"指标类型"`
	Commodity         string `description:"商品名称"`
	SjbId             int    `description:"SJB_ID"`
	UserId            int    `description:"所属用户"`
	RowsCount         int    `description:"指标数据数量"`
	DateFirst         string `description:"指标开始时间"`
	DateLast          string `description:"指标最新时间"`
	TimeLastUpdate    string `description:"最新更新时间"`
	TimeLastRequest   string `description:"下次更新时间"`
	Priority          int    `description:"更新优先级"`
	Status            int    `description:"指标状态"`
	ShortName         string `description:"指标简称"`
	UpdateDescription string `description:"更新说明"`
	ForecastFlag      int    `description:"预测标识"`
	ManualFlag        int    `description:"手动标识"`
	VariableFlag      int    `description:"有效标识"`
	MarketDataFlag    int    `description:"市场价标识"`
	CreateUser        int    `description:"创建用户"`
	CreateTime        string `description:"创建时间"`
	UpdateUser        int    `description:"更新用户"`
	UpdateTime        string `description:"更新时"`
}

type DictIndexSql struct {
	Id                int            `description:"主键" json:"ID"`
	Code              sql.NullString `description:"指标编码" json:"CODE"`
	Name              sql.NullString `description:"指标名称" json:"NAME"`
	Unit              sql.NullString `description:"单位" json:"UNIT"`
	Frequency         sql.NullString `description:"更新频率" json:"FREQUENCY"`
	Description       sql.NullString `description:"描述" json:"DESCRIPTION"`
	TableName         sql.NullString `description:"指标数据存储库表" json:"TABLE_NAME"`
	SourceType        sql.NullString `description:"指标来源，如：wind：万德;manual：手工导入;formula：公式;webisite：网页爬取" json:"SOURCE_TYPE"`
	SourceCode        sql.NullString `description:"来源编码" json:"SOURCE_CODE"`
	SourceDescription sql.NullString `description:"来源说明" json:"SOURCE_DESCRIPTION"`
	Industry          sql.NullString `description:"品种板块" json:"INDUSTRY"`
	Type              sql.NullString `description:"指标类型" json:"TYPE"`
	Commodity         sql.NullString `description:"商品名称" json:"COMMODITY"`
	SjbId             sql.NullInt32  `json:"SJB_ID"`
	UserId            sql.NullInt32  `description:"所属用户" json:"USER_ID"`
	RowsCount         sql.NullInt32  `description:"指标数据数量" json:"ROWS_COUNT"`
	DateFirst         sql.NullString `description:"指标开始时间" json:"DATE_FIRST"`
	DateLast          sql.NullString `description:"指标最新时间" json:"DATE_LAST"`
	TimeLastUpdate    sql.NullString `description:"最新更新时间" json:"TIME_LAST_UPDATE"`
	TimeLastRequest   sql.NullString `description:"下次更新时间" json:"TIME_LAST_REQUEST"`
	Priority          sql.NullInt32  `description:"更新优先级" json:"PRIORITY"`
	Status            sql.NullInt32  `description:"指标状态" json:"STATUS"`
	ShortName         sql.NullString `description:"指标简称" json:"SHORT_NAME"`
	UpdateDescription sql.NullString `description:"更新说明" json:"UPDATE_DESCRIPTION"`
	ForecastFlag      sql.NullInt32  `description:"预测标识" json:"FORECAST_FLAG"`
	ManualFlag        sql.NullInt32  `description:"手动标识" json:"MANUAL_FLAG"`
	VariableFlag      sql.NullInt32  `description:"有效标识" json:"VARIABLE_FLAG"`
	MarketDataFlag    sql.NullInt32  `description:"市场价标识" json:"MARKETDATA_FLAG"`
	CreateUser        sql.NullInt32  `description:"创建用户" json:"CREATE_USER"`
	CreateTime        sql.NullString `description:"创建时间" json:"CREATE_TIME"`
	UpdateUser        sql.NullInt32  `description:"更新用户" json:"UPDATE_USER"`
	UpdateTime        sql.NullString `description:"更新时" json:"UPDATE_TIME"`
}

type DictDataSql struct {
	Id         int             `description:"主键" json:"ID"`
	IndexId    int             `json:"INDEX_ID"`
	IndexValue sql.NullFloat64 `json:"INDEX_VALUE"`
	IndexDate  sql.NullString  `json:"INDEX_DATE"`
	UpdateTime sql.NullString  `json:"UPDATE_TIME"`
}

type DictData struct {
	Id         int `description:"主键" json:"ID"`
	IndexId    int
	IndexValue float64
	IndexDate  string
	UpdateTime string
}

func getDictIndex(sqlStatement string, pars []interface{}) (dictIndexs []DictIndex, err error) {
	//查询ZHUJI表中code='pt'的sql:SELECT * FROM ZHUJI where CODE = 'pt'
	//sqlStatement := "SELECT * FROM DICT_CATEGORY where CODE = :1"
	//sqlStatement := "SELECT * FROM DICT_INDEX WHERE SOURCE_TYPE = :1 AND ROWNUM < 11"
	stmt, err := global.OracleJy.Prepare(sqlStatement)
	if err != nil {
		panic(err)
	}
	rows, err := stmt.Query(pars...) //输入sql中对应参数的值
	if err != nil {
		panic(err)
	}

	defer rows.Close() //defer关闭查询连接
	//获取列相关信息
	//获取列相关信息
	strings, _ := rows.Columns()

	for i := 0; i < len(strings); i++ {
		fmt.Print(" ", strings[i])
	}
	fmt.Print("\n")
	for rows.Next() {
		var tmp DictIndexSql
		err = rows.Scan(&tmp.Id, &tmp.Code, &tmp.Name, &tmp.Unit, &tmp.Frequency, &tmp.Description, &tmp.TableName, &tmp.SourceType, &tmp.SourceCode, &tmp.SourceDescription, &tmp.Industry, &tmp.Type, &tmp.Commodity, &tmp.SjbId, &tmp.UserId, &tmp.RowsCount, &tmp.DateFirst, &tmp.DateLast, &tmp.TimeLastUpdate, &tmp.TimeLastRequest, &tmp.Priority, &tmp.Status, &tmp.ShortName, &tmp.UpdateDescription, &tmp.ForecastFlag, &tmp.ManualFlag, &tmp.VariableFlag, &tmp.MarketDataFlag, &tmp.CreateUser, &tmp.CreateTime, &tmp.UpdateUser, &tmp.UpdateTime)
		if err != nil {
			fmt.Printf("扫描错误:", err)
			return
		}
		dictTmp := DictIndex{
			Id:                tmp.Id,
			Code:              tmp.Code.String,
			Name:              tmp.Name.String,
			Unit:              tmp.Unit.String,
			Frequency:         tmp.Frequency.String,
			Description:       tmp.Description.String,
			TableName:         tmp.TableName.String,
			SourceType:        tmp.SourceType.String,
			SourceCode:        tmp.SourceCode.String,
			SourceDescription: tmp.SourceDescription.String,
			Industry:          tmp.Industry.String,
			Type:              tmp.Type.String,
			Commodity:         tmp.Commodity.String,
			SjbId:             int(tmp.SjbId.Int32),
			UserId:            int(tmp.UserId.Int32),
			RowsCount:         int(tmp.RowsCount.Int32),
			DateFirst:         tmp.DateFirst.String,
			DateLast:          tmp.DateLast.String,
			TimeLastUpdate:    tmp.TimeLastUpdate.String,
			TimeLastRequest:   tmp.TimeLastRequest.String,
			Priority:          int(tmp.Priority.Int32),
			Status:            int(tmp.Status.Int32),
			ShortName:         tmp.ShortName.String,
			UpdateDescription: tmp.UpdateDescription.String,
			ForecastFlag:      int(tmp.ForecastFlag.Int32),
			ManualFlag:        int(tmp.ManualFlag.Int32),
			VariableFlag:      int(tmp.VariableFlag.Int32),
			MarketDataFlag:    int(tmp.MarketDataFlag.Int32),
			CreateUser:        int(tmp.CreateUser.Int32),
			CreateTime:        tmp.CreateTime.String,
			UpdateUser:        int(tmp.UpdateUser.Int32),
			UpdateTime:        tmp.UpdateTime.String,
		}
		dictIndexs = append(dictIndexs, dictTmp)
	}
	if err = rows.Err(); err != nil {
		// handle the error here
		_ = fmt.Errorf(err.Error())
	}
	defer stmt.Close()

	/*data, err := json.Marshal(dictIndexs)
	if err != nil {
		fmt.Printf("序列化错误 err = %v\n", err)
	}
	//输出序列化后的结果 json字符串
	fmt.Printf("序列化后 = %v\n", string(data))*/
	return
}

func getDictData(sqlStatement string, pars []interface{}) (dictData []DictData, err error) {
	//查询ZHUJI表中code='pt'的sql:SELECT * FROM ZHUJI where CODE = 'pt'
	//sqlStatement := "SELECT * FROM DICT_CATEGORY where CODE = :1"
	//sqlStatement := "SELECT * FROM DICT_INDEX WHERE SOURCE_TYPE = :1 AND ROWNUM < 11"
	stmt, err := global.OracleJy.Prepare(sqlStatement)
	if err != nil {
		panic(err)
	}
	rows, err := stmt.Query(pars...) //输入sql中对应参数的值
	if err != nil {
		panic(err)
	}

	defer rows.Close() //defer关闭查询连接
	//获取列相关信息
	//获取列相关信息
	strings, _ := rows.Columns()

	for i := 0; i < len(strings); i++ {
		fmt.Print(" ", strings[i])
	}
	fmt.Print("\n")
	for rows.Next() {
		var tmp DictDataSql
		err = rows.Scan(&tmp.Id, &tmp.IndexId, &tmp.IndexValue, &tmp.IndexDate, &tmp.UpdateTime)
		if err != nil {
			fmt.Printf("扫描错误:", err)
			return
		}
		dictTmp := DictData{
			Id:         tmp.Id,
			IndexId:    tmp.IndexId,
			IndexValue: tmp.IndexValue.Float64,
			IndexDate:  tmp.IndexDate.String,
			UpdateTime: tmp.UpdateTime.String,
		}
		dictData = append(dictData, dictTmp)
	}
	if err = rows.Err(); err != nil {
		// handle the error here
		_ = fmt.Errorf(err.Error())
	}
	defer stmt.Close()

	/*data, err := json.Marshal(dictData)
	if err != nil {
		fmt.Printf("序列化错误 err = %v\n", err)
	}
	//输出序列化后的结果 json字符串
	fmt.Printf("序列化后 = %v\n", string(data))*/
	return
}
